@@ -13,15 +13,6 @@
 # endif
 #endif				/* HAVE_XLOCALE */
 
-#if defined(PTYS_ARE_PTMX) && !defined(__CYGWIN32__)
-# include <sys/resource.h>	/* for struct rlimit */
-# define _NEW_TTY_CTRL		/* to get proper defines in <termios.h> */
-#endif
-
-#ifdef __QNX__			/* autoconf someday */
-# include <process.h>
-#endif
-
 #ifdef TTY_GID_SUPPORT
 # include <grp.h>
 #endif
@@ -143,7 +134,7 @@
 # define O_NOCTTY	0
 #endif
 #ifndef ONLCR
-# define ONLCR		0		/* QNX, at least */
+# define ONLCR		0
 #endif
 
 #define CONSOLE		"/dev/console"	/* console device */
