@@ -522,6 +522,8 @@ enum {
  */
 
 enum colour_list {
+  Color_none = -2,
+  Color_transparent = -1,
   Color_fg = 0,
   Color_bg,
   minCOLOR,                   /* 2 */
@@ -684,10 +686,9 @@ enum {
  */
 #define dLocal(type,name)       type const name = this->name
 
-// for speed reasons, we assume that all latin1 characters
-// are single-width (the first unicode combining character
-// is actually 0x300, but ascii is what matters most).
-#define WCWIDTH(c) ((c) & ~0xff ? wcwidth (c) : 1)
+// for speed reasons, we assume that all codepoints 32 to 126 are
+// single-width.
+#define WCWIDTH(c)		(IN_RANGE_INC (c, 0x20, 0x7e) ? 1 : wcwidth (c))
 
 /* convert pixel dimensions to row/column values.  Everything as int32_t */
 #define Pixel2Col(x)            Pixel2Width((int32_t)(x))
@@ -700,9 +701,13 @@ enum {
 #define Height2Pixel(n)         ((int32_t)(n) * (int32_t)fheight)
 
 #define OPTION(opt)		(options & (opt))
-#define DEFAULT_OPTIONS		(Opt_scrollBar | Opt_scrollTtyOutput \
-				 | Opt_jumpScroll | Opt_secondaryScreen \
-				 | Opt_pastableTabs | Opt_intensityStyles)
+#define DEFAULT_OPTIONS		(Opt_scrollBar		\
+                                | Opt_scrollTtyOutput	\
+				| Opt_jumpScroll	\
+                                | Opt_secondaryScreen	\
+                                | Opt_secondaryScroll	\
+				| Opt_pastableTabs	\
+                                | Opt_intensityStyles)
 
 // for m >= -n, ensure remainder lies between 0..n-1
 #define MOD(m,n) (((m) + (n)) % (n))
@@ -789,6 +794,8 @@ extern void rxvt_pop_locale () NOTHROW;
 #define LINE_LONGER     0x0001 // line is continued on the next row
 #define LINE_FILTERED   0x0002 // line has been filtered
 #define LINE_COMPRESSED 0x0004 // line has been compressed (NYI)
+#define LINE_FILTER     0x0008 // line needs to be filtered before display (NYI)
+#define LINE_BIDI       0x0010 // line needs bidi (NYI)
 
 struct line_t {
    text_t *t; // terminal the text
