@@ -242,12 +242,30 @@ following four resources (shown with defaults):
 See I<COLOR AND GRAPHICS> in the @@RXVT_NAME@@(1) manpage for valid
 indices.
 
-=item mark-urls
+=item matcher
 
-Uses per-line display filtering (C<on_line_update>) to underline urls and
-make them clickable. When middle-clicked, the program specified in the
-resource C<urlLauncher> (default C<x-www-browser>) will be started with
-the URL as first argument.
+Uses per-line display filtering (C<on_line_update>) to underline text
+matching a certain pattern and make it clickable. When clicked with the
+mouse button specified in the C<matcher.button> resource (default 2, or
+middle), the program specified in the C<matcher.launcher> resource
+(default, the C<urlLauncher> resource, C<sensible-browser>) will be started
+with the matched text as first argument.  The default configuration is
+suitable for matching URLs and launching a web browser, like the
+former "mark-urls" extension.
+
+The default pattern to match URLs can be overridden with the
+C<matcher.pattern.0> resource, and additional patterns can be specified
+with numbered patterns, in a manner similar to the "selection" extension.
+The launcher can also be overridden on a per-pattern basis.
+
+Example configuration:
+
+    URxvt.perl-ext:           default,matcher
+    URxvt.urlLauncher:        sensible-browser
+    URxvt.matcher.button:     1
+    URxvt.matcher.pattern.1:  \\bwww\\.[\\w-]+\\.[\\w./?&@#-]*[\\w/-]
+    URxvt.matcher.pattern.2:  \\B(/\\S+?):(\\d+)(?=:|$)
+    URxvt.matcher.launcher.2: gvim +$2 $1
 
 =item xim-onthespot
 
@@ -348,6 +366,11 @@ for the filename):
 
    URxvt.selection-pastebin.url: http://www.ta-sa.org/files/txt/%
 
+I<Note to xrdb users:> xrdb uses the C preprocessor, which might interpret
+the double C</> characters as comment start. Use C<\057\057> instead,
+which works regardless of wether xrdb is used to parse the resource file
+or not.
+
 =item example-refresh-hooks
 
 Displays a very simple digital clock in the upper right corner of the
@@ -397,11 +420,12 @@ locale-specific way.
 =head2 Extension Objects
 
 Every perl extension is a perl class. A separate perl object is created
-for each terminal and each extension and passed as the first parameter to
-hooks. So extensions can use their C<$self> object without having to think
-about other extensions, with the exception of methods and members that
-begin with an underscore character C<_>: these are reserved for internal
-use.
+for each terminal, and each terminal has its own set of extenion objects,
+which are passed as the first parameter to hooks. So extensions can use
+their C<$self> object without having to think about clashes with other
+extensions or other terminals, with the exception of methods and members
+that begin with an underscore character C<_>: these are reserved for
+internal use.
 
 Although it isn't a C<urxvt::term> object, you can call all methods of the
 C<urxvt::term> class on this object.
@@ -1088,19 +1112,23 @@ sub DESTROY {
 }
 
 sub condvar {
-   bless \my $flag, urxvt::anyevent::condvar::
+   bless \my $flag, urxvt::anyevent::
 }
 
-sub urxvt::anyevent::condvar::broadcast {
+sub broadcast {
    ${$_[0]}++;
 }
 
-sub urxvt::anyevent::condvar::wait {
+sub wait {
    unless (${$_[0]}) {
       Carp::croak "AnyEvent->condvar blocking wait unsupported in urxvt, use a non-blocking API";
    }
 }
 
+sub one_event {
+   Carp::croak "AnyEvent->one_event blocking wait unsupported in urxvt, use a non-blocking API";
+}
+
 package urxvt::term;
 
 =head2 The C<urxvt::term> Class
